@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,11 +15,12 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-#ifndef _special_chars_h_
-#define _special_chars_h_
+#ifndef _cl_special_chars_h_
+#define _cl_special_chars_h_
 
+#include "globals.h"
 
-#include "globals.h"                    /* flag and function definitions now in <cl.h> */
-
+unsigned char *cl_string_maptable(CorpusCharset charset, int flags);
+int cl_iso_char_is_alphanumeric(unsigned char c, CorpusCharset charset);
 
 #endif
