@@ -1,13 +1,13 @@
-/* 
+/*
  *  IMS Open Corpus Workbench (CWB)
  *  Copyright (C) 1993-2006 by IMS, University of Stuttgart
  *  Copyright (C) 2007-     by the respective contributers (see file AUTHORS)
- * 
+ *
  *  This program is free software; you can redistribute it and/or modify it
  *  under the terms of the GNU General Public License as published by the
  *  Free Software Foundation; either version 2, or (at your option) any later
  *  version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful, but
  *  WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
@@ -15,24 +15,31 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
-#ifndef _TREEMACROS_H_
-#define _TREEMACROS_H_
+/**
+ * @file
+ *
+ * The preprocessor macros here are used largely in parser.y and parse_actions.c
+ */
 
-#include "../cl/macros.h"
 
-#define NEW_TNODE(n)  n = (Evaltree)cl_malloc(sizeof(union e_tree))
+#ifndef _cqp_treemacros_h_
+#define _cqp_treemacros_h_
 
+#include "../cl/cl.h"
+
+/** Macro to allocate a new Evaltree object in node-mode and fill its OP/left/right/min/max members */
 #define NEW_EVALNODE(n, _relop, _left, _right, _min, _max)                        \
                       do {                                                        \
                         n = (Evaltree)cl_malloc(sizeof(union e_tree));            \
-                        n->type = node;                                           \
+                        n->type       = node;                                     \
                         n->node.op_id = _relop;                                   \
-                        n->node.left = _left;                                     \
+                        n->node.left  = _left;                                    \
                         n->node.right = _right;                                   \
-                        n->node.min = _min;                                       \
-                        n->node.max = _max;                                       \
+                        n->node.min   = _min;                                     \
+                        n->node.max   = _max;                                     \
                       } while (0)
 
+/** Macro to allocate a new Evaltree object in leaf-mode and fill its patindex member */
 #define NEW_EVALLEAF(n, _patindex)                                                \
                       do {                                                        \
                         n = (Evaltree)cl_malloc(sizeof(union e_tree));            \
@@ -40,13 +47,7 @@
                         n->leaf.patindex = _patindex;                             \
                       } while (0)
 
+/** Macro to allocate a new Constrainttree object */
 #define NEW_BNODE(n) n = (Constrainttree)cl_malloc(sizeof(union c_tree))
 
-#define DELETE_NODE(n) cl_free(n)
-
-/* conflicts with a windows function, and is never used anyway
- * commented out in preparation for deletion
-#define DELETE(n) cl_free(n)
-*/
-
 #endif
